@@ -72,8 +72,9 @@ get_recur_count (ECalComponent *comp, time_t instance_start, time_t instance_end
 static icaltimezone *
 resolve_tzid_cb (const gchar *tzid, gpointer data)
 {
-	/* do nothing.. since we are interested only in the event date */
-	return NULL;
+	icaltimezone *zone = icaltimezone_get_builtin_timezone_from_tzid (tzid);
+
+	return zone;
 }
 
 const gchar *
@@ -1092,7 +1093,9 @@ e_gw_item_to_cal_component (EGwItem *item, ECalBackendGroupwise *cbgw)
 	/* summary */
 	text.value = e_gw_item_get_subject (item);
 	text.altrep = NULL;
-	e_cal_component_set_summary (comp, &text);
+
+	if (text.value)
+		e_cal_component_set_summary (comp, &text);
 
 	/* description */
 	description = e_gw_item_get_message (item);
@@ -1237,7 +1240,7 @@ e_gw_item_to_cal_component (EGwItem *item, ECalBackendGroupwise *cbgw)
 				if (recipient->status == E_GW_ITEM_STAT_ACCEPTED) {
 					const gchar *accept_level = e_gw_item_get_accept_level (item);
 
-					if(accept_level && !strcmp (e_gw_item_get_accept_level (item),"Tentative"))
+					if (accept_level && !strcmp (e_gw_item_get_accept_level (item),"Tentative"))
 						attendee->status = ICAL_PARTSTAT_TENTATIVE;
 					else
 						attendee->status = ICAL_PARTSTAT_ACCEPTED;
@@ -1973,7 +1976,7 @@ set_categories_changes (EGwItem *new_item, EGwItem *old_item)
 			category1  = new_category_list->data;
 			temp = old_category_list;
 			categories_matched  = FALSE;
-			for(; temp != NULL; temp = g_list_next (temp)) {
+			for (; temp != NULL; temp = g_list_next (temp)) {
 				category2 = temp->data;
 				if ( g_str_equal (category1, category2)) {
 					categories_matched = TRUE;
