@@ -39,13 +39,13 @@
 #include "camel-object.h"
 
 #define d(x)
-#define b(x) 			/* object bag */
-#define h(x) 			/* hooks */
+#define b(x)			/* object bag */
+#define h(x)			/* hooks */
 
 /* I just mashed the keyboard for these... */
-#define CAMEL_OBJECT_MAGIC           	 0x77A344ED
-#define CAMEL_OBJECT_CLASS_MAGIC     	 0xEE26A997
-#define CAMEL_INTERFACE_MAGIC     	 0xBCE137A7
+#define CAMEL_OBJECT_MAGIC		 0x77A344ED
+#define CAMEL_OBJECT_CLASS_MAGIC	 0xEE26A997
+#define CAMEL_INTERFACE_MAGIC	 0xBCE137A7
 #define CAMEL_OBJECT_FINALISED_MAGIC       0x84AC365F
 #define CAMEL_OBJECT_CLASS_FINALISED_MAGIC 0x7621ABCD
 #define CAMEL_INTERFACE_FINALISED_MAGIC    0x7CB2FE71
@@ -56,10 +56,10 @@
 typedef struct _CamelHookList {
 	GStaticRecMutex lock;
 
-	unsigned int depth:30;	/* recursive event depth */
-	unsigned int flags:2;	/* flags, see below */
+	guint depth:30;	/* recursive event depth */
+	guint flags:2;	/* flags, see below */
 
-	unsigned int list_length;
+	guint list_length;
 	struct _CamelHookPair *list;
 } CamelHookList;
 
@@ -75,25 +75,25 @@ typedef struct _CamelHookPair
 {
 	struct _CamelHookPair *next; /* next MUST be the first member */
 
-	unsigned int id:30;
-	unsigned int flags:2;	/* removed, etc */
+	guint id:30;
+	guint flags:2;	/* removed, etc */
 
-	const char *name;	/* points to the key field in the classes preplist, static memory */
+	const gchar *name;	/* points to the key field in the classes preplist, static memory */
 	union {
 		CamelObjectEventHookFunc event;
 		CamelObjectEventPrepFunc prep;
-		char *filename;
+		gchar *filename;
 	} func;
-	void *data;
+	gpointer data;
 } CamelHookPair;
 
 struct _CamelObjectBagKey {
 	struct _CamelObjectBagKey *next;
 
-	void *key;		/* the key reserved */
-	int waiters;		/* count of threads waiting for key */
+	gpointer key;		/* the key reserved */
+	gint waiters;		/* count of threads waiting for key */
 	pthread_t owner;	/* the thread that has reserved the bag for a new entry */
-	int have_owner;
+	gint have_owner;
 	GCond *cond;
 };
 
@@ -108,18 +108,18 @@ struct _CamelObjectBag {
 };
 
 /* used to tag a bag hookpair */
-static const char bag_name[] = "object:bag";
+static const gchar bag_name[] = "object:bag";
 
 /* meta-data stuff */
 static void co_metadata_free(CamelObject *obj, CamelObjectMeta *meta);
 static CamelObjectMeta *co_metadata_get(CamelObject *obj);
-static CamelHookPair *co_metadata_pair(CamelObject *obj, int create);
+static CamelHookPair *co_metadata_pair(CamelObject *obj, gint create);
 
-static const char meta_name[] = "object:meta";
+static const gchar meta_name[] = "object:meta";
 #define CAMEL_OBJECT_STATE_FILE_MAGIC "CLMD"
 
 /* interface stuff */
-static const char interface_name[] = "object:interface";
+static const gchar interface_name[] = "object:interface";
 
 /* ********************************************************************** */
 
@@ -130,7 +130,6 @@ static void camel_object_bag_remove_unlocked(CamelObjectBag *inbag, CamelObject
 #define camel_object_unget_hooks(o) \
 	(g_static_rec_mutex_unlock(&CAMEL_OBJECT(o)->hooks->lock))
 
-
 /* ********************************************************************** */
 
 /* type-lock must be recursive, for atomically creating classes */
@@ -193,7 +192,7 @@ hooks_free(CamelHookList *hooks)
 void
 camel_type_init(void)
 {
-	static int init = FALSE;
+	static gint init = FALSE;
 
 	if (init)
 		return;
@@ -231,10 +230,10 @@ cobject_finalise(CamelObject *o)
 	o->klass = NULL;
 }
 
-static int
+static gint
 cobject_getv(CamelObject *o, CamelException *ex, CamelArgGetV *args)
 {
-	int i;
+	gint i;
 	guint32 tag;
 
 	for (i=0;i<args->argc;i++) {
@@ -244,7 +243,7 @@ cobject_getv(CamelObject *o, CamelException *ex, CamelArgGetV *args)
 
 		switch (tag & CAMEL_ARG_TAG) {
 		case CAMEL_OBJECT_ARG_DESCRIPTION:
-			*arg->ca_str = (char *)o->klass->name;
+			*arg->ca_str = (gchar *)o->klass->name;
 			break;
 		case CAMEL_OBJECT_ARG_METADATA:
 			*arg->ca_ptr = co_metadata_get(o);
@@ -264,10 +263,10 @@ cobject_getv(CamelObject *o, CamelException *ex, CamelArgGetV *args)
 	return 0;
 }
 
-static int
+static gint
 cobject_setv(CamelObject *o, CamelException *ex, CamelArgV *args)
 {
-	int i;
+	gint i;
 	guint32 tag;
 
 	for (i=0;i<args->argc;i++) {
@@ -293,9 +292,9 @@ cobject_setv(CamelObject *o, CamelException *ex, CamelArgV *args)
 }
 
 static void
-cobject_free(CamelObject *o, guint32 tag, void *value)
+cobject_free(CamelObject *o, guint32 tag, gpointer value)
 {
-	switch(tag & CAMEL_ARG_TAG) {
+	switch (tag & CAMEL_ARG_TAG) {
 	case CAMEL_OBJECT_ARG_METADATA:
 		co_metadata_free(o, value);
 		break;
@@ -308,12 +307,12 @@ cobject_free(CamelObject *o, guint32 tag, void *value)
 	}
 }
 
-static char *
-cobject_meta_get(CamelObject *obj, const char * name)
+static gchar *
+cobject_meta_get(CamelObject *obj, const gchar * name)
 {
 	CamelHookPair *pair;
 	CamelObjectMeta *meta;
-	char *res = NULL;
+	gchar *res = NULL;
 
 	g_return_val_if_fail(CAMEL_IS_OBJECT (obj), NULL);
 	g_return_val_if_fail(name != NULL, NULL);
@@ -330,15 +329,15 @@ cobject_meta_get(CamelObject *obj, const char * name)
 		}
 		camel_object_unget_hooks(obj);
 	}
-	
+
 	return res;
 }
 
 static gboolean
-cobject_meta_set(CamelObject *obj, const char * name, const char *value)
+cobject_meta_set(CamelObject *obj, const gchar * name, const gchar *value)
 {
 	CamelHookPair *pair;
-	int changed = FALSE;
+	gint changed = FALSE;
 	CamelObjectMeta *meta, *metap;
 
 	g_return_val_if_fail(CAMEL_IS_OBJECT (obj), FALSE);
@@ -392,7 +391,7 @@ done:
    Version 0 of the file:
 
    version:uint32 = 0
-   count:uint32  				-- count of meta-data items
+   count:uint32				-- count of meta-data items
    ( name:string value:string ) *count		-- meta-data items
 
    Version 1 of the file adds:
@@ -401,7 +400,7 @@ done:
 
 */
 
-static int
+static gint
 cobject_state_read(CamelObject *obj, FILE *fp)
 {
 	guint32 i, count, version;
@@ -413,8 +412,8 @@ cobject_state_read(CamelObject *obj, FILE *fp)
 		return -1;
 
 	for (i=0;i<count;i++) {
-		char *name = NULL, *value = NULL;
-			
+		gchar *name = NULL, *value = NULL;
+
 		if (camel_file_util_decode_string(fp, &name) == 0
 		    && camel_file_util_decode_string(fp, &value) == 0) {
 			camel_object_meta_set(obj, name, value);
@@ -438,13 +437,13 @@ cobject_state_read(CamelObject *obj, FILE *fp)
 		}
 
 		count = MIN(count, CAMEL_ARGV_MAX);
-		
+
 		/* we batch up the properties and set them in one go */
 		argv = g_try_malloc(sizeof(CamelArgV) -
 			((CAMEL_ARGV_MAX - count) * sizeof(CamelArg)));
 		if (argv == NULL)
 			return -1;
-		
+
 		argv->argc = 0;
 		for (i=0;i<count;i++) {
 			if (camel_file_util_decode_uint32(fp, &argv->argv[argv->argc].tag) == -1)
@@ -453,7 +452,7 @@ cobject_state_read(CamelObject *obj, FILE *fp)
 			/* so far,only do strings and ints, doubles could be added,
 			   object's would require a serialisation interface */
 
-			switch(argv->argv[argv->argc].tag & CAMEL_ARG_TYPE) {
+			switch (argv->argv[argv->argc].tag & CAMEL_ARG_TYPE) {
 			case CAMEL_ARG_INT:
 			case CAMEL_ARG_BOO:
 				if (camel_file_util_decode_uint32(fp, (guint32 *) &argv->argv[argv->argc].ca_int) == -1)
@@ -483,12 +482,12 @@ cobject_state_read(CamelObject *obj, FILE *fp)
 }
 
 /* TODO: should pass exception around */
-static int
+static gint
 cobject_state_write(CamelObject *obj, FILE *fp)
 {
 	gint32 count, i;
 	CamelObjectMeta *meta = NULL, *scan;
-	int res = -1;
+	gint res = -1;
 	GSList *props = NULL, *l;
 	CamelArgGetV *arggetv = NULL;
 	CamelArgV *argv = NULL;
@@ -587,7 +586,6 @@ abort:
 	return res;
 }
 
-
 static void
 cobject_class_init(CamelObjectClass *klass)
 {
@@ -614,30 +612,28 @@ cobject_class_finalise(CamelObjectClass * klass)
 	g_free(klass);
 }
 
-
 /* CamelInterface base methods */
 
-static void
+G_GNUC_NORETURN static void
 cinterface_init(CamelObject *o, CamelObjectClass *klass)
 {
 	g_error("Cannot instantiate interfaces, trying to instantiate '%s'", klass->name);
-	abort();
 }
 
-static int
+static gint
 cinterface_getv(CamelObject *o, CamelException *ex, CamelArgGetV *args)
 {
 	return 0;
 }
 
-static int
+static gint
 cinterface_setv(CamelObject *o, CamelException *ex, CamelArgV *args)
 {
 	return 0;
 }
 
 static void
-cinterface_free(CamelObject *o, guint32 tag, void *value)
+cinterface_free(CamelObject *o, guint32 tag, gpointer value)
 {
 	/* NOOP */
 }
@@ -682,7 +678,7 @@ camel_object_get_type(void)
 							   0, sizeof(CamelInterface),
 							   cinterface_class_init, cinterface_class_finalise,
 							   cinterface_init, NULL);
-							   
+
 	}
 
 	return camel_object_type;
@@ -699,9 +695,9 @@ camel_type_class_init(CamelObjectClass *klass, CamelObjectClass *type)
 }
 
 static CamelType
-co_type_register(CamelType parent, const char * name,
-		 /*unsigned int ver, unsigned int rev,*/
-		 size_t object_size, size_t klass_size,
+co_type_register(CamelType parent, const gchar * name,
+		 /*guint ver, guint rev,*/
+		 gsize object_size, gsize klass_size,
 		 CamelObjectClassInitFunc class_init,
 		 CamelObjectClassFinalizeFunc class_finalise,
 		 CamelObjectInitFunc object_init,
@@ -709,7 +705,7 @@ co_type_register(CamelType parent, const char * name,
 {
 	CamelObjectClass *klass;
 	/*int offset;
-	  size_t size;*/
+	  gsize size;*/
 
 	TYPE_LOCK();
 
@@ -775,7 +771,7 @@ co_type_register(CamelType parent, const char * name,
 	klass->finalise = object_finalise;
 
 	/* setup before class init, incase class init func uses the type or looks it up ? */
-	g_hash_table_insert(type_table, (void *)name, klass);
+	g_hash_table_insert(type_table, (gpointer)name, klass);
 
 	camel_type_class_init(klass, klass);
 
@@ -785,9 +781,9 @@ co_type_register(CamelType parent, const char * name,
 }
 
 CamelType
-camel_type_register(CamelType parent, const char * name,
-		    /*unsigned int ver, unsigned int rev,*/
-		    size_t object_size, size_t klass_size,
+camel_type_register(CamelType parent, const gchar * name,
+		    /*guint ver, guint rev,*/
+		    gsize object_size, gsize klass_size,
 		    CamelObjectClassInitFunc class_init,
 		    CamelObjectClassFinalizeFunc class_finalise,
 		    CamelObjectInitFunc object_init,
@@ -802,8 +798,8 @@ camel_type_register(CamelType parent, const char * name,
 }
 
 CamelType
-camel_interface_register(CamelType parent, const char *name,
-			 size_t class_size,
+camel_interface_register(CamelType parent, const gchar *name,
+			 gsize class_size,
 			 CamelObjectClassInitFunc class_init,
 			 CamelObjectClassFinalizeFunc class_finalise)
 {
@@ -858,7 +854,7 @@ camel_object_new(CamelType type)
 }
 
 void
-camel_object_ref(void *vo)
+camel_object_ref(gpointer vo)
 {
 	register CamelObject *o = vo;
 
@@ -873,14 +869,14 @@ camel_object_ref(void *vo)
 }
 
 void
-camel_object_unref(void *vo)
+camel_object_unref(gpointer vo)
 {
 	register CamelObject *o = vo;
 	register CamelObjectClass *klass, *k;
 	CamelHookList *hooks = NULL;
 
 	g_return_if_fail(CAMEL_IS_OBJECT(o));
-	
+
 	klass = o->klass;
 
 	if (o->hooks)
@@ -934,7 +930,7 @@ camel_object_unref(void *vo)
 	CLASS_UNLOCK(klass);
 }
 
-const char *
+const gchar *
 camel_type_to_name(CamelType type)
 {
 	if (type == NULL)
@@ -949,17 +945,17 @@ camel_type_to_name(CamelType type)
 	return "(Junk class)";
 }
 
-CamelType camel_name_to_type(const char *name)
+CamelType camel_name_to_type(const gchar *name)
 {
 	/* TODO: Load a class off disk (!) */
 
 	return g_hash_table_lookup(type_table, name);
 }
 
-static char *
+static gchar *
 desc_data(CamelObject *o, guint32 ok)
 {
-	char *what;
+	gchar *what;
 
 	if (o == NULL)
 		what = g_strdup("NULL OBJECT");
@@ -977,7 +973,7 @@ desc_data(CamelObject *o, guint32 ok)
 		what = g_strdup_printf("finalised CLASS");
 	else if (o->magic == CAMEL_INTERFACE_FINALISED_MAGIC)
 		what = g_strdup_printf("finalised INTERFACE");
-	else 
+	else
 		what = g_strdup_printf("junk data");
 
 	return what;
@@ -989,9 +985,9 @@ desc_data(CamelObject *o, guint32 ok)
 	? 1 : check_magic_fail(o, ctype, omagic)
 
 static gboolean
-check_magic_fail(void *o, CamelType ctype, guint32 omagic)
+check_magic_fail(gpointer o, CamelType ctype, guint32 omagic)
 {
-	char *what, *to;
+	gchar *what, *to;
 
 	what = desc_data(o, omagic);
 	to = desc_data((CamelObject *)ctype, CAMEL_OBJECT_CLASS_MAGIC);
@@ -1002,7 +998,7 @@ check_magic_fail(void *o, CamelType ctype, guint32 omagic)
 				what = g_strdup_printf("OBJECT '%s'", ((CamelObject *)o)->klass->name);
 			else
 				what = g_strdup_printf("OBJECT '%s'", ((CamelObjectClass *)o)->name);
-		}		
+		}
 		if (to == NULL)
 			to = g_strdup_printf("OBJECT '%s'", ctype->name);
 		g_warning("Trying to check %s is %s", what, to);
@@ -1078,7 +1074,7 @@ camel_object_cast(CamelObject *o, CamelType ctype)
 		k = k->parent;
 	}
 
-	g_warning("Object %p (class '%s') doesn't have '%s' in its hierarchy", (void *) o, o->klass->name, ctype->name);
+	g_warning("Object %p (class '%s') doesn't have '%s' in its hierarchy", (gpointer) o, o->klass->name, ctype->name);
 
 	return NULL;
 }
@@ -1120,7 +1116,7 @@ camel_interface_cast(CamelObjectClass *k, CamelType ctype)
 }
 
 static CamelHookPair *
-co_find_pair(CamelObjectClass *klass, const char *name)
+co_find_pair(CamelObjectClass *klass, const gchar *name)
 {
 	CamelHookPair *hook;
 
@@ -1135,7 +1131,7 @@ co_find_pair(CamelObjectClass *klass, const char *name)
 }
 
 static CamelHookPair *
-co_find_pair_ptr(CamelObjectClass *klass, const char *name)
+co_find_pair_ptr(CamelObjectClass *klass, const gchar *name)
 {
 	CamelHookPair *hook;
 
@@ -1151,7 +1147,7 @@ co_find_pair_ptr(CamelObjectClass *klass, const char *name)
 
 /* class functions */
 void
-camel_object_class_add_event(CamelObjectClass *klass, const char *name, CamelObjectEventPrepFunc prep)
+camel_object_class_add_event(CamelObjectClass *klass, const gchar *name, CamelObjectEventPrepFunc prep)
 {
 	CamelHookPair *pair;
 
@@ -1185,7 +1181,7 @@ camel_object_class_add_interface(CamelObjectClass *klass, CamelType itype)
 	CamelHookPair *pair;
 	CamelType iscan;
 	GPtrArray *interfaces;
-	int i;
+	gint i;
 
 	if (!camel_interface_is(itype, camel_interface_type)) {
 		g_warning("Cannot add an interface not derived from CamelInterface on class '%s'", klass->name);
@@ -1273,19 +1269,19 @@ camel_object_get_hooks(CamelObject *o)
 		}
 		pthread_mutex_unlock(&lock);
 	}
-	
+
 	g_static_rec_mutex_lock(&o->hooks->lock);
-	
-	return o->hooks;	
+
+	return o->hooks;
 }
 
-unsigned int
-camel_object_hook_event(void *vo, const char * name, CamelObjectEventHookFunc func, void *data)
+guint
+camel_object_hook_event(gpointer vo, const gchar * name, CamelObjectEventHookFunc func, gpointer data)
 {
 	CamelObject *obj = vo;
 	CamelHookPair *pair, *hook;
 	CamelHookList *hooks;
-	int id;
+	gint id;
 
 	g_return_val_if_fail(CAMEL_IS_OBJECT (obj), 0);
 	g_return_val_if_fail(name != NULL, 0);
@@ -1298,7 +1294,7 @@ camel_object_hook_event(void *vo, const char * name, CamelObjectEventHookFunc fu
 		pair = co_find_pair_ptr(obj->klass, interface_name);
 		if (pair) {
 			GPtrArray *interfaces = pair->data;
-			int i;
+			gint i;
 
 			for (i=0;i<interfaces->len;i++) {
 				hook = co_find_pair(interfaces->pdata[i], name);
@@ -1334,7 +1330,7 @@ setup:
 }
 
 void
-camel_object_remove_event(void *vo, unsigned int id)
+camel_object_remove_event(gpointer vo, guint id)
 {
 	CamelObject *obj = vo;
 	CamelHookList *hooks;
@@ -1379,7 +1375,7 @@ camel_object_remove_event(void *vo, unsigned int id)
 }
 
 void
-camel_object_unhook_event(void *vo, const char * name, CamelObjectEventHookFunc func, void *data)
+camel_object_unhook_event(gpointer vo, const gchar * name, CamelObjectEventHookFunc func, gpointer data)
 {
 	CamelObject *obj = vo;
 	CamelHookList *hooks;
@@ -1423,17 +1419,17 @@ camel_object_unhook_event(void *vo, const char * name, CamelObjectEventHookFunc
 	camel_object_unget_hooks(obj);
 
 	g_warning("camel_object_unhook_event: cannot find hook/data pair %p/%p in an instance of '%s' attached to '%s'",
-		  (void *) func, data, obj->klass->name, name);
+		  (gpointer) func, data, obj->klass->name, name);
 }
 
 void
-camel_object_trigger_event(void *vo, const char * name, void *event_data)
+camel_object_trigger_event(gpointer vo, const gchar * name, gpointer event_data)
 {
 	CamelObject *obj = vo;
 	CamelHookList *hooks;
 	CamelHookPair *pair, **pairs, *parent, *hook;
-	int i, size;
-	const char *prepname;
+	gint i, size;
+	const gchar *prepname;
 
 	g_return_if_fail (CAMEL_IS_OBJECT (obj));
 	g_return_if_fail (name);
@@ -1449,7 +1445,7 @@ camel_object_trigger_event(void *vo, const char * name, void *event_data)
 	pair = co_find_pair_ptr(obj->klass, interface_name);
 	if (pair) {
 		GPtrArray *interfaces = pair->data;
-		
+
 		for (i=0;i<interfaces->len;i++) {
 			hook = co_find_pair(interfaces->pdata[i], name);
 			if (hook)
@@ -1475,7 +1471,7 @@ trigger_interface:
 	/* lock the object for hook emission */
 	camel_object_ref(obj);
 	hooks = camel_object_get_hooks(obj);
-	
+
 	if (hooks->list) {
 		/* first, copy the items in the list, and say we're in an event */
 		hooks->depth++;
@@ -1519,8 +1515,8 @@ trigger_interface:
 	camel_object_unref(obj);
 }
 
-void *
-camel_object_get_interface(void *vo, CamelType itype)
+gpointer
+camel_object_get_interface(gpointer vo, CamelType itype)
 {
 	CamelObject *obj = vo;
 	CamelHookPair *pair;
@@ -1531,7 +1527,7 @@ camel_object_get_interface(void *vo, CamelType itype)
 	pair = co_find_pair_ptr(obj->klass, interface_name);
 	if (pair) {
 		GPtrArray *interfaces = pair->data;
-		int i;
+		gint i;
 
 		for (i=0;i<interfaces->len;i++) {
 			if (camel_interface_is((CamelType)interfaces->pdata[i], itype))
@@ -1545,12 +1541,12 @@ camel_object_get_interface(void *vo, CamelType itype)
 }
 
 /* get/set arg methods */
-int camel_object_set(void *vo, CamelException *ex, ...)
+gint camel_object_set(gpointer vo, CamelException *ex, ...)
 {
 	CamelArgV args;
 	CamelObject *o = vo;
 	CamelObjectClass *klass = o->klass;
-	int ret = 0;
+	gint ret = 0;
 
 	g_return_val_if_fail(CAMEL_IS_OBJECT(o), -1);
 
@@ -1566,19 +1562,19 @@ int camel_object_set(void *vo, CamelException *ex, ...)
 	return ret;
 }
 
-int camel_object_setv(void *vo, CamelException *ex, CamelArgV *args)
+gint camel_object_setv(gpointer vo, CamelException *ex, CamelArgV *args)
 {
 	g_return_val_if_fail(CAMEL_IS_OBJECT(vo), -1);
 
 	return ((CamelObject *)vo)->klass->setv(vo, ex, args);
 }
 
-int camel_object_get(void *vo, CamelException *ex, ...)
+gint camel_object_get(gpointer vo, CamelException *ex, ...)
 {
 	CamelObject *o = vo;
 	CamelArgGetV args;
 	CamelObjectClass *klass = o->klass;
-	int ret = 0;
+	gint ret = 0;
 
 	g_return_val_if_fail(CAMEL_IS_OBJECT(o), -1);
 
@@ -1594,13 +1590,13 @@ int camel_object_get(void *vo, CamelException *ex, ...)
 	return ret;
 }
 
-void *camel_object_get_ptr(void *vo, CamelException *ex, int tag)
+gpointer camel_object_get_ptr(gpointer vo, CamelException *ex, gint tag)
 {
 	CamelObject *o = vo;
 	CamelArgGetV args;
 	CamelObjectClass *klass = o->klass;
-	int ret = 0;
-	void *val = NULL;
+	gint ret = 0;
+	gpointer val = NULL;
 
 	g_return_val_if_fail(CAMEL_IS_OBJECT(o), NULL);
 	g_return_val_if_fail((tag & CAMEL_ARG_TYPE) == CAMEL_ARG_OBJ
@@ -1619,13 +1615,13 @@ void *camel_object_get_ptr(void *vo, CamelException *ex, int tag)
 		return val;
 }
 
-int camel_object_get_int(void *vo, CamelException *ex, int tag)
+gint camel_object_get_int(gpointer vo, CamelException *ex, gint tag)
 {
 	CamelObject *o = vo;
 	CamelArgGetV args;
 	CamelObjectClass *klass = o->klass;
-	int ret = 0;
-	int val = 0;
+	gint ret = 0;
+	gint val = 0;
 
 	g_return_val_if_fail(CAMEL_IS_OBJECT(o), 0);
 	g_return_val_if_fail((tag & CAMEL_ARG_TYPE) == CAMEL_ARG_INT
@@ -1643,7 +1639,7 @@ int camel_object_get_int(void *vo, CamelException *ex, int tag)
 		return val;
 }
 
-int camel_object_getv(void *vo, CamelException *ex, CamelArgGetV *args)
+gint camel_object_getv(gpointer vo, CamelException *ex, CamelArgGetV *args)
 {
 	g_return_val_if_fail(CAMEL_IS_OBJECT(vo), -1);
 
@@ -1652,7 +1648,7 @@ int camel_object_getv(void *vo, CamelException *ex, CamelArgGetV *args)
 
 /* NB: If this doesn't return NULL, then you must unget_hooks when done */
 static CamelHookPair *
-co_metadata_pair(CamelObject *obj, int create)
+co_metadata_pair(CamelObject *obj, gint create)
 {
 	CamelHookPair *pair;
 	CamelHookList *hooks;
@@ -1731,15 +1727,15 @@ co_metadata_free(CamelObject *obj, CamelObjectMeta *meta)
 
 /**
  * camel_object_meta_get:
- * @vo: 
- * @name: 
- * 
+ * @vo:
+ * @name:
+ *
  * Get a meta-data on an object.
- * 
+ *
  * Return value: NULL if the meta-data is not set.
  **/
-char *
-camel_object_meta_get(void *vo, const char * name)
+gchar *
+camel_object_meta_get(gpointer vo, const gchar * name)
 {
 	CamelObject *obj = vo;
 
@@ -1751,10 +1747,10 @@ camel_object_meta_get(void *vo, const char * name)
 
 /**
  * camel_object_meta_set:
- * @vo: 
+ * @vo:
  * @name: Name of meta-data.  Should be prefixed with class of setter.
  * @value: Value to set.  If NULL, then the meta-data is removed.
- * 
+ *
  * Set a meta-data item on an object.  If the object supports persistent
  * data, then the meta-data will be persistent across sessions.
  *
@@ -1766,7 +1762,7 @@ camel_object_meta_get(void *vo, const char * name)
  * metadata.
  **/
 gboolean
-camel_object_meta_set(void *vo, const char * name, const char *value)
+camel_object_meta_set(gpointer vo, const gchar * name, const gchar *value)
 {
 	CamelObject *obj = vo;
 
@@ -1774,7 +1770,7 @@ camel_object_meta_set(void *vo, const char * name, const char *value)
 	g_return_val_if_fail(name != NULL, FALSE);
 
 	if (obj->klass->meta_set(obj, name, value)) {
-		camel_object_trigger_event(obj, "meta_changed", (void *)name);
+		camel_object_trigger_event(obj, "meta_changed", (gpointer)name);
 		return TRUE;
 	}
 
@@ -1783,19 +1779,19 @@ camel_object_meta_set(void *vo, const char * name, const char *value)
 
 /**
  * camel_object_state_read:
- * @vo: 
- * 
+ * @vo:
+ *
  * Read persistent object state from object_set(CAMEL_OBJECT_STATE_FILE).
- * 
+ *
  * Return value: -1 on error.
  **/
-int camel_object_state_read(void *vo)
+gint camel_object_state_read(gpointer vo)
 {
 	CamelObject *obj = vo;
-	int res = -1;
-	char *file;
+	gint res = -1;
+	gchar *file;
 	FILE *fp;
-	char magic[4];
+	gchar magic[4];
 
 	camel_object_get(vo, NULL, CAMEL_OBJECT_STATE_FILE, &file, NULL);
 	if (file == NULL)
@@ -1818,17 +1814,17 @@ int camel_object_state_read(void *vo)
 
 /**
  * camel_object_state_write:
- * @vo: 
- * 
+ * @vo:
+ *
  * Write persistent state to the file as set by object_set(CAMEL_OBJECT_STATE_FILE).
- * 
+ *
  * Return value: -1 on error.
  **/
-int camel_object_state_write(void *vo)
+gint camel_object_state_write(gpointer vo)
 {
 	CamelObject *obj = vo;
-	int res = -1;
-	char *file, *savename, *dirname;
+	gint res = -1;
+	gchar *file, *savename, *dirname;
 	FILE *fp;
 
 	camel_object_get(vo, NULL, CAMEL_OBJECT_STATE_FILE, &file, NULL);
@@ -1861,7 +1857,7 @@ int camel_object_state_write(void *vo)
 }
 
 /* free an arg object, you can only free objects 1 at a time */
-void camel_object_free(void *vo, guint32 tag, void *value)
+void camel_object_free(gpointer vo, guint32 tag, gpointer value)
 {
 	g_return_if_fail(CAMEL_IS_OBJECT(vo));
 
@@ -1869,7 +1865,7 @@ void camel_object_free(void *vo, guint32 tag, void *value)
 
 	   Add a 'const' bit to the arg type field,
 	   specifying that the object should not be freed.
-	   
+
 	   And, add free handlers for any pointer objects which are
 	   not const.  The free handlers would be hookpairs off of the
 	   class.
@@ -1885,9 +1881,9 @@ void camel_object_free(void *vo, guint32 tag, void *value)
 }
 
 static void
-object_class_dump_tree_rec(CamelType root, int depth)
+object_class_dump_tree_rec(CamelType root, gint depth)
 {
-	char *p;
+	gchar *p;
 #ifdef CAMEL_OBJECT_TRACK_INSTANCES
 	struct _CamelObject *o;
 #endif
@@ -1904,7 +1900,7 @@ object_class_dump_tree_rec(CamelType root, int depth)
 			CamelHookPair *pair = root->hooks;
 
 			while (pair) {
-				printf("%s  event '%s' prep %p\n", p, pair->name, (void *) pair->func.prep);
+				printf("%s  event '%s' prep %p\n", p, pair->name, (gpointer) pair->func.prep);
 				pair = pair->next;
 			}
 		}
@@ -1942,16 +1938,16 @@ camel_object_class_dump_tree(CamelType root)
 
 /**
  * camel_object_bag_new:
- * @hash: 
- * @equal: 
- * @keycopy: 
- * @keyfree: 
- * 
+ * @hash:
+ * @equal:
+ * @keycopy:
+ * @keyfree:
+ *
  * Allocate a new object bag.  Object bag's are key'd hash tables of
  * camel-objects which can be updated atomically using transaction
  * semantics.
- * 
- * Return value: 
+ *
+ * Return value:
  **/
 CamelObjectBag *
 camel_object_bag_new(GHashFunc hash, GEqualFunc equal, CamelCopyFunc keycopy, GFreeFunc keyfree)
@@ -1970,7 +1966,7 @@ camel_object_bag_new(GHashFunc hash, GEqualFunc equal, CamelCopyFunc keycopy, GF
 }
 
 static void
-save_object(void *key, CamelObject *o, GPtrArray *objects)
+save_object(gpointer key, CamelObject *o, GPtrArray *objects)
 {
 	g_ptr_array_add(objects, o);
 }
@@ -1979,14 +1975,14 @@ void
 camel_object_bag_destroy(CamelObjectBag *bag)
 {
 	GPtrArray *objects = g_ptr_array_new();
-	int i;
+	gint i;
 
 	g_assert(bag->reserved == NULL);
 
 	g_hash_table_foreach(bag->object_table, (GHFunc)save_object, objects);
 	for (i=0;i<objects->len;i++)
 		camel_object_bag_remove(bag, objects->pdata[i]);
-	
+
 	g_ptr_array_free(objects, TRUE);
 	g_hash_table_destroy(bag->object_table);
 	g_hash_table_destroy(bag->key_table);
@@ -1995,7 +1991,7 @@ camel_object_bag_destroy(CamelObjectBag *bag)
 
 /* must be called with ref_lock held */
 static void
-co_bag_unreserve(CamelObjectBag *bag, const void *key)
+co_bag_unreserve(CamelObjectBag *bag, gconstpointer key)
 {
 	struct _CamelObjectBagKey *res, *resp;
 
@@ -2012,11 +2008,11 @@ co_bag_unreserve(CamelObjectBag *bag, const void *key)
 	g_assert(res->have_owner && pthread_equal(res->owner, pthread_self()));
 
 	if (res->waiters > 0) {
-		b(printf("unreserve bag '%s', waking waiters\n", (char *)key));
+		b(printf("unreserve bag '%s', waking waiters\n", (gchar *)key));
 		res->have_owner = FALSE;
 		g_cond_signal(res->cond);
 	} else {
-		b(printf("unreserve bag '%s', no waiters, freeing reservation\n", (char *)key));
+		b(printf("unreserve bag '%s', no waiters, freeing reservation\n", (gchar *)key));
 		resp->next = res->next;
 		bag->free_key(res->key);
 		g_cond_free(res->cond);
@@ -2026,20 +2022,20 @@ co_bag_unreserve(CamelObjectBag *bag, const void *key)
 
 /**
  * camel_object_bag_add:
- * @bag: 
- * @key: 
- * @vo: 
- * 
+ * @bag:
+ * @key:
+ * @vo:
+ *
  * Add an object @vo to the object bag @bag.  The @key MUST have
  * previously been reserved using camel_object_bag_reserve().
  **/
 void
-camel_object_bag_add(CamelObjectBag *bag, const void *key, void *vo)
+camel_object_bag_add(CamelObjectBag *bag, gconstpointer key, gpointer vo)
 {
 	CamelObject *o = vo;
 	CamelHookList *hooks;
 	CamelHookPair *pair;
-	void *k;
+	gpointer k;
 
 	hooks = camel_object_get_hooks(o);
 	REF_LOCK();
@@ -2069,25 +2065,25 @@ camel_object_bag_add(CamelObjectBag *bag, const void *key, void *vo)
 	g_hash_table_insert(bag->key_table, vo, k);
 
 	co_bag_unreserve(bag, key);
-	
+
 	REF_UNLOCK();
 	camel_object_unget_hooks(o);
 }
 
 /**
  * camel_object_bag_get:
- * @bag: 
- * @key: 
- * 
+ * @bag:
+ * @key:
+ *
  * Lookup an object by @key.  If the key is currently reserved, then
  * wait until the key has been committed before continuing.
- * 
+ *
  * Return value: NULL if the object corresponding to @key is not
  * in the bag.  Otherwise a ref'd object pointer which the caller owns
  * the ref to.
  **/
-void *
-camel_object_bag_get(CamelObjectBag *bag, const void *key)
+gpointer
+camel_object_bag_get(CamelObjectBag *bag, gconstpointer key)
 {
 	CamelObject *o;
 
@@ -2095,7 +2091,7 @@ camel_object_bag_get(CamelObjectBag *bag, const void *key)
 
 	o = g_hash_table_lookup(bag->object_table, key);
 	if (o) {
-		b(printf("object bag get '%s' = %p\n", (char *)key, o));
+		b(printf("object bag get '%s' = %p\n", (gchar *)key, o));
 
 		/* we use the same lock as the refcount */
 		o->ref_count++;
@@ -2110,7 +2106,7 @@ camel_object_bag_get(CamelObjectBag *bag, const void *key)
 		}
 
 		if (res) {
-			b(printf("object bag get '%s', reserved, waiting\n", (char *)key));
+			b(printf("object bag get '%s', reserved, waiting\n", (gchar *)key));
 
 			res->waiters++;
 			g_assert(!res->have_owner || !pthread_equal(res->owner, pthread_self()));
@@ -2122,7 +2118,7 @@ camel_object_bag_get(CamelObjectBag *bag, const void *key)
 			if (o)
 				o->ref_count++;
 
-			b(printf("object bag get '%s', finished waiting, got %p\n", (char *)key, o));
+			b(printf("object bag get '%s', finished waiting, got %p\n", (gchar *)key, o));
 
 			/* we don't actually reserve it */
 			res->owner = pthread_self();
@@ -2130,29 +2126,29 @@ camel_object_bag_get(CamelObjectBag *bag, const void *key)
 			co_bag_unreserve(bag, key);
 		}
 	}
-	
+
 	REF_UNLOCK();
-	
+
 	return o;
 }
 
 /**
  * camel_object_bag_peek:
- * @bag: 
- * @key: 
- * 
+ * @bag:
+ * @key:
+ *
  * Lookup the object @key in @bag, ignoring any reservations.  If it
  * isn't committed, then it isn't considered.  This should only be
  * used where reliable transactional-based state is not required.
- * 
+ *
  * Unlike other 'peek' operations, the object is still reffed if
  * found.
  *
  * Return value: A referenced object, or NULL if @key is not
  * present in the bag.
  **/
-void *
-camel_object_bag_peek(CamelObjectBag *bag, const void *key)
+gpointer
+camel_object_bag_peek(CamelObjectBag *bag, gconstpointer key)
 {
 	CamelObject *o;
 
@@ -2171,9 +2167,9 @@ camel_object_bag_peek(CamelObjectBag *bag, const void *key)
 
 /**
  * camel_object_bag_reserve:
- * @bag: 
- * @key: 
- * 
+ * @bag:
+ * @key:
+ *
  * Reserve a key in the object bag.  If the key is already reserved in
  * another thread, then wait until the reservation has been committed.
  *
@@ -2184,11 +2180,11 @@ camel_object_bag_peek(CamelObjectBag *bag, const void *key)
  *
  * You may reserve multiple keys from the same thread, but they should
  * always be reserved in the same order, to avoid deadlocks.
- * 
- * Return value: 
+ *
+ * Return value:
  **/
-void *
-camel_object_bag_reserve(CamelObjectBag *bag, const void *key)
+gpointer
+camel_object_bag_reserve(CamelObjectBag *bag, gconstpointer key)
 {
 	CamelObject *o;
 
@@ -2207,7 +2203,7 @@ camel_object_bag_reserve(CamelObjectBag *bag, const void *key)
 		}
 
 		if (res) {
-			b(printf("bag reserve %s, already reserved, waiting\n", (char *)key));
+			b(printf("bag reserve %s, already reserved, waiting\n", (gchar *)key));
 			g_assert(!res->have_owner || !pthread_equal(res->owner, pthread_self()));
 			res->waiters++;
 			g_cond_wait(res->cond, ref_lock);
@@ -2215,19 +2211,19 @@ camel_object_bag_reserve(CamelObjectBag *bag, const void *key)
 			/* incase its slipped in while we were waiting */
 			o = g_hash_table_lookup(bag->object_table, key);
 			if (o) {
-				b(printf("finished wait, someone else created '%s' = %p\n", (char *)key, o));
+				b(printf("finished wait, someone else created '%s' = %p\n", (gchar *)key, o));
 				o->ref_count++;
 				/* in which case we dont need to reserve the bag either */
 				res->owner = pthread_self();
 				res->have_owner = TRUE;
 				co_bag_unreserve(bag, key);
 			} else {
-				b(printf("finished wait, now owner of '%s'\n", (char *)key));
+				b(printf("finished wait, now owner of '%s'\n", (gchar *)key));
 				res->owner = pthread_self();
 				res->have_owner = TRUE;
 			}
 		} else {
-			b(printf("bag reserve %s, no key, reserving\n", (char *)key));
+			b(printf("bag reserve %s, no key, reserving\n", (gchar *)key));
 			res = g_malloc(sizeof(*res));
 			res->waiters = 0;
 			res->key = bag->copy_key(key);
@@ -2238,7 +2234,7 @@ camel_object_bag_reserve(CamelObjectBag *bag, const void *key)
 			bag->reserved = res;
 		}
 	}
-	
+
 	REF_UNLOCK();
 
 	return o;
@@ -2246,13 +2242,13 @@ camel_object_bag_reserve(CamelObjectBag *bag, const void *key)
 
 /**
  * camel_object_bag_abort:
- * @bag: 
- * @key: 
- * 
+ * @bag:
+ * @key:
+ *
  * Abort a key reservation.
  **/
 void
-camel_object_bag_abort(CamelObjectBag *bag, const void *key)
+camel_object_bag_abort(CamelObjectBag *bag, gconstpointer key)
 {
 	REF_LOCK();
 
@@ -2263,19 +2259,19 @@ camel_object_bag_abort(CamelObjectBag *bag, const void *key)
 
 /**
  * camel_object_bag_rekey:
- * @bag: 
- * @o: 
- * @newkey: 
- * 
+ * @bag:
+ * @o:
+ * @newkey:
+ *
  * Re-key an object, atomically.  The key for object @o is set to
  * @newkey, in an atomic manner.
  *
  * It is an api (fatal) error if @o is not currently in the bag.
  **/
 void
-camel_object_bag_rekey(CamelObjectBag *bag, void *o, const void *newkey)
+camel_object_bag_rekey(CamelObjectBag *bag, gpointer o, gconstpointer newkey)
 {
-	void *oldkey;
+	gpointer oldkey;
 
 	REF_LOCK();
 
@@ -2294,7 +2290,7 @@ camel_object_bag_rekey(CamelObjectBag *bag, void *o, const void *newkey)
 }
 
 static void
-save_bag(void *key, CamelObject *o, GPtrArray *list)
+save_bag(gpointer key, CamelObject *o, GPtrArray *list)
 {
 	/* we have the refcount lock already */
 	o->ref_count++;
@@ -2322,7 +2318,7 @@ static void
 camel_object_bag_remove_unlocked(CamelObjectBag *inbag, CamelObject *o, CamelHookList *hooks)
 {
 	CamelHookPair *pair, *parent;
-	void *oldkey;
+	gpointer oldkey;
 	CamelObjectBag *bag;
 
 	parent = (CamelHookPair *)&hooks->list;
@@ -2349,7 +2345,7 @@ camel_object_bag_remove_unlocked(CamelObjectBag *inbag, CamelObject *o, CamelHoo
 }
 
 void
-camel_object_bag_remove(CamelObjectBag *inbag, void *vo)
+camel_object_bag_remove(CamelObjectBag *inbag, gpointer vo)
 {
 	CamelObject *o = vo;
 	CamelHookList *hooks;
@@ -2361,14 +2357,14 @@ camel_object_bag_remove(CamelObjectBag *inbag, void *vo)
 	REF_LOCK();
 
 	camel_object_bag_remove_unlocked(inbag, o, hooks);
-		
+
 	REF_UNLOCK();
 	camel_object_unget_hooks(o);
 }
 
 /* ********************************************************************** */
 
-void *camel_iterator_new(CamelIteratorVTable *klass, size_t size)
+gpointer camel_iterator_new(CamelIteratorVTable *klass, gsize size)
 {
 	CamelIterator *it;
 
@@ -2380,27 +2376,27 @@ void *camel_iterator_new(CamelIteratorVTable *klass, size_t size)
 	return it;
 }
 
-const void *camel_iterator_next(void *it, CamelException *ex)
+gconstpointer camel_iterator_next(gpointer it, CamelException *ex)
 {
 	g_assert(it);
 	return ((CamelIterator *)it)->klass->next(it, ex);
 }
 
-void camel_iterator_reset(void *it)
+void camel_iterator_reset(gpointer it)
 {
 	g_assert(it);
 	((CamelIterator *)it)->klass->reset(it);
 }
 
-int camel_iterator_length(void *it)
+gint camel_iterator_length(gpointer it)
 {
 	g_assert(it);
 	g_return_val_if_fail(((CamelIterator *)it)->klass->length != NULL, 0);
-	
+
 	return ((CamelIterator *)it)->klass->length(it);
 }
 
-void camel_iterator_free(void *it)
+void camel_iterator_free(gpointer it)
 {
 	if (it) {
 		if (((CamelIterator *)it)->klass->free)
