@@ -20,7 +20,6 @@
  *
  */
 
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -39,7 +38,6 @@
 #include "camel-sasl.h"
 #include "camel-service.h"
 
-
 #define w(x)
 
 static CamelObjectClass *parent_class = NULL;
@@ -53,7 +51,7 @@ static void
 camel_sasl_class_init (CamelSaslClass *camel_sasl_class)
 {
 	parent_class = camel_type_get_global_classfuncs (CAMEL_OBJECT_TYPE);
-	
+
 	/* virtual method definition */
 	camel_sasl_class->challenge = sasl_challenge;
 }
@@ -70,7 +68,7 @@ CamelType
 camel_sasl_get_type (void)
 {
 	static CamelType type = CAMEL_INVALID_TYPE;
-	
+
 	if (type == CAMEL_INVALID_TYPE) {
 		type = camel_type_register (CAMEL_OBJECT_TYPE,
 					    "CamelSasl",
@@ -81,11 +79,10 @@ camel_sasl_get_type (void)
 					    NULL,
 					    (CamelObjectFinalizeFunc) camel_sasl_finalize);
 	}
-	
+
 	return type;
 }
 
-
 static GByteArray *
 sasl_challenge (CamelSasl *sasl, GByteArray *token, CamelException *ex)
 {
@@ -111,7 +108,7 @@ GByteArray *
 camel_sasl_challenge (CamelSasl *sasl, GByteArray *token, CamelException *ex)
 {
 	g_return_val_if_fail (CAMEL_IS_SASL (sasl), NULL);
-	
+
 	return CS_CLASS (sasl)->challenge (sasl, token, ex);
 }
 
@@ -126,11 +123,11 @@ camel_sasl_challenge (CamelSasl *sasl, GByteArray *token, CamelException *ex)
  *
  * Returns: the base64 encoded challenge string
  **/
-char *
-camel_sasl_challenge_base64 (CamelSasl *sasl, const char *token, CamelException *ex)
+gchar *
+camel_sasl_challenge_base64 (CamelSasl *sasl, const gchar *token, CamelException *ex)
 {
 	GByteArray *token_binary, *ret_binary;
-	char *ret;
+	gchar *ret;
 
 	g_return_val_if_fail (CAMEL_IS_SASL (sasl), NULL);
 
@@ -175,7 +172,6 @@ camel_sasl_authenticated (CamelSasl *sasl)
 	return sasl->authenticated;
 }
 
-
 /**
  * camel_sasl_new:
  * @service_name: the SASL service name
@@ -187,16 +183,16 @@ camel_sasl_authenticated (CamelSasl *sasl)
  * supported.
  **/
 CamelSasl *
-camel_sasl_new (const char *service_name, const char *mechanism, CamelService *service)
+camel_sasl_new (const gchar *service_name, const gchar *mechanism, CamelService *service)
 {
 	CamelSasl *sasl;
-	
+
 	g_return_val_if_fail (service_name != NULL, NULL);
 	g_return_val_if_fail (mechanism != NULL, NULL);
 	g_return_val_if_fail (CAMEL_IS_SERVICE (service), NULL);
-	
+
 	/* We don't do ANONYMOUS here, because it's a little bit weird. */
-	
+
 	if (!strcmp (mechanism, "CRAM-MD5"))
 		sasl = (CamelSasl *) camel_object_new (CAMEL_SASL_CRAM_MD5_TYPE);
 	else if (!strcmp (mechanism, "DIGEST-MD5"))
@@ -224,7 +220,7 @@ camel_sasl_new (const char *service_name, const char *mechanism, CamelService *s
 	sasl->service_name = g_strdup (service_name);
 	sasl->service = service;
 	camel_object_ref (service);
-	
+
 	return sasl;
 }
 
@@ -239,7 +235,7 @@ GList *
 camel_sasl_authtype_list (gboolean include_plain)
 {
 	GList *types = NULL;
-	
+
 	types = g_list_prepend (types, &camel_sasl_cram_md5_authtype);
 	types = g_list_prepend (types, &camel_sasl_digest_md5_authtype);
 #ifdef HAVE_KRB5
@@ -251,7 +247,7 @@ camel_sasl_authtype_list (gboolean include_plain)
 	types = g_list_prepend (types, &camel_sasl_ntlm_authtype);
 	if (include_plain)
 		types = g_list_prepend (types, &camel_sasl_plain_authtype);
-	
+
 	return types;
 }
 
@@ -263,7 +259,7 @@ camel_sasl_authtype_list (gboolean include_plain)
  * it is supported.
  **/
 CamelServiceAuthType *
-camel_sasl_authtype (const char *mechanism)
+camel_sasl_authtype (const gchar *mechanism)
 {
 	if (!strcmp (mechanism, "CRAM-MD5"))
 		return &camel_sasl_cram_md5_authtype;
