@@ -1,7 +1,7 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
 /* e-cell-renderer-color.c
  *
- * Copyright (C) 2007 Novell, Inc.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU Lesser General Public
@@ -57,20 +57,28 @@ cell_renderer_color_get_size (GtkCellRenderer *cell,
 	gint color_height = 16;
 	gint calc_width;
 	gint calc_height;
+	gfloat xalign;
+	gfloat yalign;
+	guint xpad;
+	guint ypad;
 
-	calc_width  = (gint) cell->xpad * 2 + color_width;
-	calc_height = (gint) cell->ypad * 2 + color_height;
+	g_object_get (
+		cell, "xalign", &xalign, "yalign", &yalign,
+		"xpad", &xpad, "ypad", &ypad, NULL);
+
+	calc_width  = (gint) xpad * 2 + color_width;
+	calc_height = (gint) ypad * 2 + color_height;
 
 	if (cell_area && color_width > 0 && color_height > 0) {
 		if (x_offset) {
 			*x_offset = (((gtk_widget_get_direction (widget) == GTK_TEXT_DIR_RTL) ?
-					(1.0 - cell->xalign) : cell->xalign) *
+					(1.0 - xalign) : xalign) *
 					(cell_area->width - calc_width));
 			*x_offset = MAX (*x_offset, 0);
 		}
 
 		if (y_offset) {
-			*y_offset = (cell->yalign *
+			*y_offset =(yalign *
 				(cell_area->height - calc_height));
 			*y_offset = MAX (*y_offset, 0);
 		}
@@ -99,6 +107,8 @@ cell_renderer_color_render (GtkCellRenderer *cell,
 	GdkRectangle pix_rect;
 	GdkRectangle draw_rect;
 	GdkGC *gc;
+	guint xpad;
+	guint ypad;
 
 	priv = E_CELL_RENDERER_COLOR_GET_PRIVATE (cell);
 
@@ -110,10 +120,12 @@ cell_renderer_color_render (GtkCellRenderer *cell,
 		&pix_rect.x, &pix_rect.y,
 		&pix_rect.width, &pix_rect.height);
 
-	pix_rect.x += cell_area->x + cell->xpad;
-	pix_rect.y += cell_area->y + cell->ypad;
-	pix_rect.width  -= cell->xpad * 2;
-	pix_rect.height -= cell->ypad * 2;
+	g_object_get (cell, "xpad", &xpad, "ypad", &ypad, NULL);
+
+	pix_rect.x += cell_area->x + xpad;
+	pix_rect.y += cell_area->y + ypad;
+	pix_rect.width  -= xpad * 2;
+	pix_rect.height -= ypad * 2;
 
 	if (!gdk_rectangle_intersect (cell_area, &pix_rect, &draw_rect) ||
 	    !gdk_rectangle_intersect (expose_area, &draw_rect, &draw_rect))
@@ -218,7 +230,7 @@ e_cell_renderer_color_init (ECellRendererColor *cellcolor)
 {
 	cellcolor->priv = E_CELL_RENDERER_COLOR_GET_PRIVATE (cellcolor);
 
-	GTK_CELL_RENDERER (cellcolor)->xpad = 4;
+	g_object_set (cellcolor, "xpad", 4, NULL);
 }
 
 GtkCellRenderer *
