@@ -43,7 +43,7 @@ struct _ESourceSelectorPrivate {
 	GtkTreeRowReference *saved_primary_selection;
 	ESourceGroup *primary_source_group;
 
-	int rebuild_model_idle_id;
+	gint rebuild_model_idle_id;
 
 	gboolean toggled_last;
 	gboolean checkboxes_shown;
@@ -71,7 +71,7 @@ enum {
 	DATA_DROPPED,
 	NUM_SIGNALS
 };
-static unsigned int signals[NUM_SIGNALS] = { 0 };
+static guint signals[NUM_SIGNALS] = { 0 };
 
 G_DEFINE_TYPE (ESourceSelector, e_source_selector, GTK_TYPE_TREE_VIEW)
 
@@ -116,7 +116,7 @@ static void
 e_cell_renderer_safe_toggle_class_init (ECellRendererSafeToggleClass *klass)
 {
 	GtkCellRendererClass *rndr_class;
-	
+
 	rndr_class = GTK_CELL_RENDERER_CLASS (klass);
 	rndr_class->activate = safe_toggle_activate;
 }
@@ -156,7 +156,6 @@ create_rebuild_data (ESourceSelector *selector)
 	return rebuild_data;
 }
 
-
 static void
 free_rebuild_data (ESourceSelectorRebuildData *rebuild_data)
 {
@@ -220,7 +219,7 @@ find_source_iter (ESourceSelector *selector, ESource *source, GtkTreeIter *paren
 		do {
 			if (gtk_tree_model_iter_children (model, source_iter, parent_iter)) {
 				do {
-					void *data;
+					gpointer data;
 
 					gtk_tree_model_get (model, source_iter, 0, &data, -1);
 					g_assert (E_IS_SOURCE (data));
@@ -245,8 +244,8 @@ static gboolean
 rebuild_existing_cb (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, gpointer data)
 {
 	ESourceSelectorRebuildData *rebuild_data = data;
-	void *node;
-	const char *uid;
+	gpointer node;
+	const gchar *uid;
 
 	gtk_tree_model_get (model, iter, 0, &node, -1);
 
@@ -433,7 +432,7 @@ rebuild_model (ESourceSelector *selector)
 	free_rebuild_data (rebuild_data);
 }
 
-static int
+static gint
 on_idle_rebuild_model_callback (ESourceSelector *selector)
 {
 	rebuild_model (selector);
@@ -462,7 +461,7 @@ toggle_cell_data_func (GtkTreeViewColumn *column,
 		       GtkTreeIter *iter,
 		       ESourceSelector *selector)
 {
-	void *data;
+	gpointer data;
 
 	gtk_tree_model_get (model, iter, 0, &data, -1);
 
@@ -488,7 +487,7 @@ text_cell_data_func (GtkTreeViewColumn *column,
 		     GtkTreeIter *iter,
 		     ESourceSelector *selector)
 {
-	void *data;
+	gpointer data;
 
 	gtk_tree_model_get (model, iter, 0, &data, -1);
 
@@ -521,7 +520,7 @@ pixbuf_cell_data_func (GtkTreeViewColumn *column,
 		       GtkTreeIter *iter,
 		       ESourceSelector *selector)
 {
-	void *data;
+	gpointer data;
 
 	gtk_tree_model_get (model, iter, 0, &data, -1);
 
@@ -572,7 +571,7 @@ selection_func (GtkTreeSelection *selection,
 		ESourceSelector *selector)
 {
 	GtkTreeIter iter;
-	void *data;
+	gpointer data;
 
 	if (selector->priv->toggled_last) {
 		selector->priv->toggled_last = FALSE;
@@ -586,7 +585,6 @@ selection_func (GtkTreeSelection *selection,
 	if (! gtk_tree_model_get_iter (model, &iter, path))
 		return FALSE;
 
-
 	gtk_tree_model_get (model, &iter, 0, &data, -1);
 	if (E_IS_SOURCE_GROUP (data)) {
 		g_object_unref (data);
@@ -600,7 +598,6 @@ selection_func (GtkTreeSelection *selection,
 	return TRUE;
 }
 
-
 /* Callbacks.  */
 
 static void
@@ -630,14 +627,14 @@ text_cell_edited_cb (ESourceSelector *selector,
 
 static void
 cell_toggled_callback (GtkCellRendererToggle *renderer,
-		       const char *path_string,
+		       const gchar *path_string,
 		       ESourceSelector *selector)
 {
 	GtkTreeModel *model = GTK_TREE_MODEL (selector->priv->tree_store);
 	GtkTreePath *path = gtk_tree_path_new_from_string (path_string);
 	GtkTreeIter iter;
 	ESource *source;
-	void *data;
+	gpointer data;
 
 	if (! gtk_tree_model_get_iter (model, &iter, path)) {
 		gtk_tree_path_free (path);
@@ -1029,7 +1026,7 @@ source_selector_popup_menu (GtkWidget *widget)
 
 /* Initialization.  */
 static gboolean
-ess_bool_accumulator(GSignalInvocationHint *ihint, GValue *out, const GValue *in, void *data)
+ess_bool_accumulator(GSignalInvocationHint *ihint, GValue *out, const GValue *in, gpointer data)
 {
 	gboolean val = g_value_get_boolean(in);
 
@@ -1117,8 +1114,8 @@ group_search_function   (GtkTreeModel *model,
 			 GtkTreeIter *iter,
 			 gpointer dummy)
 {
-	void *data;
-	const char *name = NULL;
+	gpointer data;
+	const gchar *name = NULL;
 	gboolean status = TRUE;
 
 	gtk_tree_model_get (model, iter, 0, &data, -1);
@@ -1134,7 +1131,6 @@ group_search_function   (GtkTreeModel *model,
 	if (name)
 		status = g_ascii_strncasecmp (name, key, strlen(key)) != 0;
 
-
 	g_object_unref (data);
 
 	return status;
@@ -1200,7 +1196,6 @@ e_source_selector_init (ESourceSelector *selector)
 	g_signal_connect (G_OBJECT (selector), "row-expanded", G_CALLBACK (row_expanded_callback), selector);
 }
 
-
 /* Public API.  */
 
 /**
@@ -1309,7 +1304,6 @@ e_source_selector_free_selection (GSList *list)
 	g_slist_free (list);
 }
 
-
 /**
  * e_source_selector_show_selection:
  * @selector: An ESourceSelector widget
@@ -1493,6 +1487,7 @@ e_source_selector_edit_primary_selection (ESourceSelector *selector)
 
 	/* XXX Because we stuff three renderers in a single column,
 	 *     we have to manually hunt for the text renderer. */
+	renderer = NULL;
 	list = gtk_tree_view_column_get_cell_renderers (column);
 	while (list != NULL) {
 		renderer = list->data;
@@ -1531,7 +1526,7 @@ e_source_selector_peek_primary_selection (ESourceSelector *selector)
 	GtkTreeModel *model;
 	GtkTreeIter iter;
 	gboolean have_iter = FALSE;
-	void *data = NULL;
+	gpointer data = NULL;
 
 	g_return_val_if_fail (E_IS_SOURCE_SELECTOR (selector), NULL);
 
